==> haskell-process-extras-0.7.4-270-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-EVPuBXQWnA46vy17aJ0OvW
key:                  process-extras-0.7.4-EVPuBXQWnA46vy17aJ0OvW
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  c785d7af1f531485db08a9b8bc3fb1a1
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-process-extras
hs-libraries:         HSprocess-extras-0.7.4-EVPuBXQWnA46vy17aJ0OvW
depends:
    ListLike-4.7.7-KgqMRE40wAEEVgBcs3oTRH base-4.15.1.0
    bytestring-0.10.12.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 generic-deriving-1.14.2-GCy9rEaX8utGJ7xwwnqdcZ
    mtl-2.2.2 process-1.6.13.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-273-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-HwQsB2DMl6iHeP5bApYz0F
key:                  process-extras-0.7.4-HwQsB2DMl6iHeP5bApYz0F
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  427152f2e60bba9426bc87bb33caa8d2
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-process-extras
hs-libraries:         HSprocess-extras-0.7.4-HwQsB2DMl6iHeP5bApYz0F
depends:
    ListLike-4.7.8-3IW5Gn1vYyf5JDqEI2DZT base-4.15.1.0
    bytestring-0.10.12.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 generic-deriving-1.14.2-3E9zS7JbpEu1d6aF2swDis
    mtl-2.2.2 process-1.6.13.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
